@@ -107,6 +107,9 @@ even if it's just a single space character.
 Rendering doesn't affect the HTML document's state, so you can add to or
 otherwise manipulate the HTML after you've stringified it.
 
+The HTML instance may also be returned directly as the "iterable content"
+in a WSGI app function.
+
 
 Creating XHTML
 --------------
@@ -123,12 +126,23 @@ with the appropriate XHTML minimized tag syntax. For example::
    <p></p>
    <br />
 
+Version History (in Brief)
+--------------------------
+
+- 1.6 added .raw_text() and and WSGI compatibility
+- 1.5 added XHTML support
+- 1.3 added more documentation, more tests
+- 1.2 added special-case klass / class attribute
+- 1.1 added escaping control
+- 1.0 was the initial release
+
 ----
 
 This code is copyright 2009 eKit.com Inc (http://www.ekit.com/)
 See the end of the source file for the license of use.
+XHTML support was contributed by Michael Haubenwallner.
 '''
-__version__ = '1.5'
+__version__ = '1.6'
 
 import unittest
 import cgi
@@ -164,6 +178,9 @@ class HTML(object):
             self.content.append(e)
         return e
     def text(self, text, escape=True):
+        '''Add text to the document. If "escape" is True any characters
+        special to HTML will be escaped.
+        '''
         if escape:
             text = cgi.escape(text)
         # adding text
@@ -171,6 +188,11 @@ class HTML(object):
             self.stack[-1].content.append(text)
         else:
             self.content.append(text)
+    def raw_text(self, text):
+        '''Add raw, unescaped text to the document. This is useful for
+        explicitly adding HTML code or entities.
+        '''
+        return self.text(text, escape=False)
     def __call__(self, *content, **kw):
         # customising a tag with content or attributes
         if content:
@@ -205,6 +227,8 @@ class HTML(object):
             s += join.join(map(str, self.content))   
             s += join + '</%s>'%self.name
         return s
+    def __iter__(self):
+        return iter([str(self)])
 
 class XHTML(HTML):
     '''Easily generate XHTML.
